async fn run_due_phase(
ctx: &PhaseContext<'_>,
phase: CreditRegistrationPhase,
state: &CreditRegistrationPhaseState,
) -> Result<()>Expand description
Runs one due phase, and schedules the next run.
async fn run_due_phase(
ctx: &PhaseContext<'_>,
phase: CreditRegistrationPhase,
state: &CreditRegistrationPhaseState,
) -> Result<()>Runs one due phase, and schedules the next run.